=== modified file 'loggerhead/changecache.py'
--- loggerhead/changecache.py	2008-10-24 02:26:05 +0000
+++ loggerhead/changecache.py	2009-03-18 20:57:19 +0000
@@ -70,11 +70,10 @@
         else:
             return self._unserialize(filechange[0])
 
-    def add(self, revid_obj_pairs):
-        for (r, d) in revid_obj_pairs:
-            self.cursor.execute(
-                "insert into revisiondata (revid, data) values (?, ?)",
-                (r, self._serialize(d)))
+    def add(self, revid, object):
+        self.cursor.execute(
+            "insert into revisiondata (revid, data) values (?, ?)",
+            (revid, self._serialize(object)))
         self.connection.commit()
 
 
@@ -93,26 +92,10 @@
         self._lock = LockFile(os.path.join(cache_path, 'filechange-lock'))
 
     @with_lock
-    def get_file_changes(self, entries):
-        out = []
-        missing_entries = []
-        missing_entry_indices = []
+    def get_file_changes(self, entry):
         cache = FakeShelf(self._changes_filename)
-        for entry in entries:
-            changes = cache.get(entry.revid)
-            if changes is not None:
-                out.append(changes)
-            else:
-                missing_entries.append(entry)
-                missing_entry_indices.append(len(out))
-                out.append(None)
-        if missing_entries:
-            missing_changes = self.history.get_file_changes_uncached(
-                                  missing_entries)
-            revid_changes_pairs = []
-            for i, entry, changes in zip(
-                missing_entry_indices, missing_entries, missing_changes):
-                revid_changes_pairs.append((entry.revid, changes))
-                out[i] = changes
-            cache.add(revid_changes_pairs)
-        return out
+        changes = cache.get(entry.revid)
+        if changes is None:
+            changes = self.history.get_file_changes_uncached(entry)
+            cache.add(entry.revid, changes)
+        return changes

=== modified file 'loggerhead/controllers/inventory_ui.py'
--- loggerhead/controllers/inventory_ui.py	2009-03-03 20:43:12 +0000
+++ loggerhead/controllers/inventory_ui.py	2009-03-19 00:44:05 +0000
@@ -146,8 +146,7 @@
                 revno_url = 'head:'
             else:
                 revno_url = history.get_revno(revid)
-            # add parent & merge-point branch-nick info, in case it's useful
-            history.get_branch_nicks([ change ])
+            history.add_branch_nicks(change)
 
             # Create breadcrumb trail for the path within the branch
             branch_breadcrumbs = util.branch_breadcrumbs(path, rev_tree, 'files')

=== modified file 'loggerhead/controllers/revision_ui.py'
--- loggerhead/controllers/revision_ui.py	2009-03-18 04:54:35 +0000
+++ loggerhead/controllers/revision_ui.py	2009-03-19 00:44:05 +0000
@@ -28,7 +28,6 @@
 from loggerhead import util
 from loggerhead.controllers import TemplatedBranchView
 from loggerhead.controllers.filediff_ui import diff_chunks_for_file
-from loggerhead.history import rich_filename
 
 
 DEFAULT_LINE_COUNT_LIMIT = 3000
@@ -36,77 +35,11 @@
 def dq(p):
     return urllib.quote(urllib.quote(p, safe=''))
 
+
 class RevisionUI(TemplatedBranchView):
 
     template_path = 'loggerhead.templates.revision'
 
-    def _parse_diffs(self, old_tree, new_tree, delta, specific_path):
-        """
-        Return a list of processed diffs, in the format::
-
-            list(
-                filename: str,
-                file_id: str,
-                chunks: list(
-                    diff: list(
-                        old_lineno: int,
-                        new_lineno: int,
-                        type: str('context', 'delete', or 'insert'),
-                        line: str,
-                    ),
-                ),
-            )
-        """
-        if specific_path:
-            fid = new_tree.path2id(specific_path)
-            kind = new_tree.kind(fid)
-            chunks=diff_chunks_for_file(fid, old_tree, new_tree)
-            return [util.Container(
-                filename=rich_filename(specific_path, kind), file_id=fid,
-                chunks=chunks)]
-
-        process = []
-        out = []
-
-        for old_path, new_path, fid, \
-            kind, text_modified, meta_modified in delta.renamed:
-            if text_modified:
-                process.append((new_path, fid, kind))
-        for path, fid, kind, text_modified, meta_modified in delta.modified:
-            process.append((path, fid, kind))
-        for path, fid, kind in delta.added:
-            if kind == 'file':
-                process.append((path, fid, kind))
-        for path, fid, kind in delta.removed:
-            if kind == 'file':
-                process.append((path, fid, kind))
-
-        process.sort()
-
-        for new_path, fid, kind in process:
-            out.append(util.Container(
-                filename=rich_filename(new_path, kind), file_id=fid,
-                chunks=[]))
-
-        return out
-
-    def get_changes_with_diff(self, change, compare_revid, specific_path):
-        h = self._history
-        if compare_revid is None:
-            if change.parents:
-                compare_revid = change.parents[0].revid
-            else:
-                compare_revid = 'null:'
-
-        rev_tree1 = h._branch.repository.revision_tree(compare_revid)
-        rev_tree2 = h._branch.repository.revision_tree(change.revid)
-        delta = rev_tree2.changes_from(rev_tree1)
-
-        changes = h.parse_delta(delta)
-
-        return changes, self._parse_diffs(
-            rev_tree1, rev_tree2, delta, specific_path)
-
     def get_values(self, path, kwargs, headers):
         h = self._history
         revid = self.get_revid()
@@ -135,25 +68,37 @@
         util.fill_in_navigation(navigation)
 
         change = h.get_changes([revid])[0]
+
+        if compare_revid is None:
+            if change.parents:
+                cr = change.parents[0].revid
+            else:
+                cr = 'null:'
+        else:
+            cr = compare_revid
+
         if path in ('', '/'):
             path = None
-        change.changes, diffs = self.get_changes_with_diff(change, compare_revid, path)
+
+        old_tree = h._branch.repository.revision_tree(cr)
+        new_tree = h._branch.repository.revision_tree(change.revid)
+        file_changes = h.file_changes_from_revision_trees(
+            old_tree, new_tree)
+
         link_data = {}
         path_to_id = {}
-        if compare_revid is None:
-            if change.parents:
-                cr = change.parents[0].revid
-            else:
-                cr = 'null:'
+        if path:
+            diff_chunks = diff_chunks_for_file(
+                new_tree.path2id(path), old_tree, new_tree)
         else:
-            cr = compare_revid
-        for i, item in enumerate(diffs):
-            item.index = i
-            link_data['diff-' + str(i)] = '%s/%s/%s' % (
-                dq(revid), dq(cr), dq(item.file_id))
-            path_to_id[item.filename] = 'diff-' + str(i)
-        # add parent & merge-point branch-nick info, in case it's useful
-        h.get_branch_nicks([change])
+            diff_chunks = None
+            for i, item in enumerate(file_changes.text_changes):
+                item.index = i
+                link_data['diff-' + str(i)] = '%s/%s/%s' % (
+                    dq(revid), dq(cr), dq(item.file_id))
+                path_to_id[item.filename] = 'diff-' + str(i)
+
+        h.add_branch_nicks(change)
 
         # Directory Breadcrumbs
         directory_breadcrumbs = (
@@ -166,7 +111,8 @@
             'branch': self._branch,
             'revid': revid,
             'change': change,
-            'diffs': diffs,
+            'file_changes': file_changes,
+            'diff_chunks': diff_chunks,
             'link_data': simplejson.dumps(link_data),
             'specific_path': path,
             'json_specific_path': simplejson.dumps(path),

=== modified file 'loggerhead/controllers/revlog_ui.py'
--- loggerhead/controllers/revlog_ui.py	2009-03-16 23:01:40 +0000
+++ loggerhead/controllers/revlog_ui.py	2009-03-19 00:44:05 +0000
@@ -13,13 +13,14 @@
 
         revid = urllib.unquote(self.args[0])
 
-        changes = list(history.get_changes([revid]))
-        history.add_changes(changes)
-        history.get_branch_nicks(changes)
+        change = history.get_changes([revid])[0]
+        file_changes = history.get_file_changes(change)
+        history.add_branch_nicks(change)
 
         return {
             'branch': self._branch,
-            'entry': changes[0],
+            'entry': change,
+            'file_changes': file_changes,
             'util': util,
             'revid': revid,
             'url': self._branch.context_url,

=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2009-03-16 23:21:29 +0000
+++ loggerhead/history.py	2009-03-19 00:44:05 +0000
@@ -44,6 +44,7 @@
 
 import bzrlib
 import bzrlib.branch
+import bzrlib.delta
 import bzrlib.diff
 import bzrlib.errors
 import bzrlib.progress
@@ -129,6 +130,38 @@
     def __len__(self):
         return len(self.revid_list)
 
+class FileChangeReporter(object):
+    def __init__(self):
+        self.added = []
+        self.modified = []
+        self.renamed = []
+        self.removed = []
+        self.text_changes = []
+    def report(self, file_id, paths, versioned, renamed, modified,
+               exe_change, kind):
+        if modified not in ('unchanged', 'kind changed'):
+            self.text_changes.append(util.Container(
+                filename=rich_filename(paths[1], kind[0]),
+                file_id=file_id))
+        if versioned == 'added':
+            self.added.append(util.Container(
+                filename=rich_filename(paths[1], kind),
+                file_id=file_id, kind=kind[1]))
+        elif versioned == 'removed':
+            self.removed.append(util.Container(
+                filename=rich_filename(paths[1], kind),
+                file_id=file_id, kind=kind[0]))
+        elif renamed:
+            self.renamed.append(util.Container(
+                old_filename=rich_filename(paths[0], kind[0]),
+                new_filename=rich_filename(paths[1], kind[1]),
+                file_id=file_id,
+                text_modified=modified == 'modified'))
+        else:
+            self.modified.append(util.Container(
+                filename=rich_filename(paths[1], kind),
+                file_id=file_id))
+
 
 class History (object):
     """Decorate a branch to provide information for rendering.
@@ -457,31 +490,28 @@
 
         return [d[revnos][1] for revnos in d.keys()]
 
-    def get_branch_nicks(self, changes):
+    def add_branch_nicks(self, change):
         """
-        given a list of changes from L{get_changes}, fill in the branch nicks
-        on all parents and merge points.
+        given a 'change', fill in the branch nicks on all parents and merge
+        points.
         """
         fetch_set = set()
-        for change in changes:
-            for p in change.parents:
-                fetch_set.add(p.revid)
-            for p in change.merge_points:
-                fetch_set.add(p.revid)
+        for p in change.parents:
+            fetch_set.add(p.revid)
+        for p in change.merge_points:
+            fetch_set.add(p.revid)
         p_changes = self.get_changes(list(fetch_set))
         p_change_dict = dict([(c.revid, c) for c in p_changes])
-        for change in changes:
-            # arch-converted branches may not have merged branch info :(
-            for p in change.parents:
-                if p.revid in p_change_dict:
-                    p.branch_nick = p_change_dict[p.revid].branch_nick
-                else:
-                    p.branch_nick = '(missing)'
-            for p in change.merge_points:
-                if p.revid in p_change_dict:
-                    p.branch_nick = p_change_dict[p.revid].branch_nick
-                else:
-                    p.branch_nick = '(missing)'
+        for p in change.parents:
+            if p.revid in p_change_dict:
+                p.branch_nick = p_change_dict[p.revid].branch_nick
+            else:
+                p.branch_nick = '(missing)'
+        for p in change.merge_points:
+            if p.revid in p_change_dict:
+                p.branch_nick = p_change_dict[p.revid].branch_nick
+            else:
+                p.branch_nick = '(missing)'
 
     def get_changes(self, revid_list):
         """Return a list of changes objects for the given revids.
@@ -526,32 +556,6 @@
 
         return [self._change_from_revision(rev) for rev in rev_list]
 
-    def _get_deltas_for_revisions_with_trees(self, revisions):
-        """Produce a list of revision deltas.
-
-        Note that the input is a sequence of REVISIONS, not revision_ids.
-        Trees will be held in memory until the generator exits.
-        Each delta is relative to the revision's lefthand predecessor.
-        (This is copied from bzrlib.)
-        """
-        required_trees = set()
-        for revision in revisions:
-            required_trees.add(revision.revid)
-            required_trees.update([p.revid for p in revision.parents[:1]])
-        trees = dict((t.get_revision_id(), t) for
-                     t in self._branch.repository.revision_trees(
-                         required_trees))
-        ret = []
-        for revision in revisions:
-            if not revision.parents:
-                old_tree = self._branch.repository.revision_tree(
-                    bzrlib.revision.NULL_REVISION)
-            else:
-                old_tree = trees[revision.parents[0].revid]
-            tree = trees[revision.revid]
-            ret.append(tree.changes_from(old_tree))
-        return ret
-
     def _change_from_revision(self, revision):
         """
         Given a bzrlib Revision, return a processed "change" for use in
@@ -581,22 +585,24 @@
         }
         return util.Container(entry)
 
-    def get_file_changes_uncached(self, entries):
-        delta_list = self._get_deltas_for_revisions_with_trees(entries)
-
-        return [self.parse_delta(delta) for delta in delta_list]
-
-    def get_file_changes(self, entries):
+    def get_file_changes_uncached(self, entry):
+        repo = self._branch.repository
+        if entry.parents:
+            old_tree = repo.revision_tree(entry.parents[0].revid)
+        else:
+            old_tree = repo.revision_tree(bzrlib.revision.NULL_REVISION)
+        new_tree = repo.revision_tree(entry.revid)
+        return self.file_changes_from_revision_trees(old_tree, new_tree)
+
+    def get_file_changes(self, entry):
         if self._file_change_cache is None:
-            return self.get_file_changes_uncached(entries)
+            return self.get_file_changes_uncached(entry)
         else:
-            return self._file_change_cache.get_file_changes(entries)
-
-    def add_changes(self, entries):
-        changes_list = self.get_file_changes(entries)
-
-        for entry, changes in zip(entries, changes_list):
-            entry.changes = changes
+            return self._file_change_cache.get_file_changes(entry)
+
+    def add_changes(self, entry):
+        changes = self.get_file_changes(entry)
+        entry.changes = changes
 
     def get_file(self, file_id, revid):
         "returns (path, filename, data)"
@@ -608,7 +614,7 @@
             path = '/' + path
         return path, inv_entry.name, rev_tree.get_file_text(file_id)
 
-    def parse_delta(self, delta):
+    def file_changes_from_revision_trees(self, old_tree, new_tree):
         """
         Return a nested data structure containing the changes in a delta::
 
@@ -618,31 +624,16 @@
             modified: list(
                 filename: str,
                 file_id: str,
-            )
+            ),
+            text_changes: list((filename, file_id)),
         """
-        added = []
-        modified = []
-        renamed = []
-        removed = []
-
-        for path, fid, kind in delta.added:
-            added.append(util.Container(
-                filename=rich_filename(path, kind), file_id=fid, kind=kind))
-
-        for path, fid, kind, text_modified, meta_modified in delta.modified:
-            modified.append(util.Container(
-                filename=rich_filename(path, kind), file_id=fid))
-
-        for old_path, new_path, fid, kind, text_modified, meta_modified in \
-                delta.renamed:
-            renamed.append(util.Container(
-                old_filename=rich_filename(old_path, kind),
-                new_filename=rich_filename(new_path, kind), file_id=fid,
-                text_modified=text_modified))
-
-        for path, fid, kind in delta.removed:
-            removed.append(util.Container(
-                filename=rich_filename(path, kind), file_id=fid, kind=kind))
-
-        return util.Container(added=added, renamed=renamed,
-                              removed=removed, modified=modified)
+        reporter = FileChangeReporter()
+
+        bzrlib.delta.report_changes(new_tree.iter_changes(old_tree), reporter)
+
+        return util.Container(
+            added=sorted(reporter.added, key=lambda x:x.filename),
+            renamed=sorted(reporter.renamed, key=lambda x:x.new_filename),
+            removed=sorted(reporter.removed, key=lambda x:x.filename),
+            modified=sorted(reporter.modified, key=lambda x:x.filename),
+            text_changes=sorted(reporter.text_changes))

=== modified file 'loggerhead/static/javascript/diff.js'
--- loggerhead/static/javascript/diff.js	2009-03-17 06:51:29 +0000
+++ loggerhead/static/javascript/diff.js	2009-03-18 04:08:41 +0000
@@ -162,14 +162,16 @@
 Y.on(
   "domready", function () {
     Y.all(".show_if_js").removeClass("show_if_js");
-    Y.all("#list-files a").on(
-      'click',
-      function (e) {
-        e.preventDefault();
-        var path = decodeURIComponent(e.target.get('href').split('#')[1]);
-        window.location.hash = '#' + path;
-        zoom_to_diff(path);
-      });
+    if (!specific_path) {
+      Y.all("#list-files a").on(
+        'click',
+        function (e) {
+          e.preventDefault();
+          var path = decodeURIComponent(e.target.get('href').split('#')[1]);
+          window.location.hash = '#' + path;
+          zoom_to_diff(path);
+        });
+    }
     var diffs = Y.all('.diff');
     if (diffs == null) return;
     diffs.each(

=== modified file 'loggerhead/templatefunctions.py'
--- loggerhead/templatefunctions.py	2009-03-17 06:32:25 +0000
+++ loggerhead/templatefunctions.py	2009-03-19 00:18:46 +0000
@@ -38,7 +38,7 @@
 
 
 @templatefunc
-def file_change_summary(url, entry, style='normal', currently_showing=None):
+def file_change_summary(url, entry, file_changes, style='normal', currently_showing=None):
     if style == 'fragment':
         def file_link(filename):
             if currently_showing and filename == currently_showing:
@@ -53,16 +53,15 @@
                 url(['/revision', entry.revno]), '#' + filename, cgi.escape(filename),
                 cgi.escape(entry.revno), cgi.escape(filename))
     return _pt('revisionfilechanges').expand(
-        url=url, entry=entry, file_link=file_link,
-        currently_showing=currently_showing, **templatefunctions)
+        entry=entry, file_changes=file_changes, file_link=file_link, **templatefunctions)
 
 
 @templatefunc
-def revisioninfo(url, branch, entry, include_file_list=False, currently_showing=None):
+def revisioninfo(url, branch, entry, file_changes=None, currently_showing=None):
     from loggerhead import util
     return _pt('revisioninfo').expand(
         url=url, change=entry, branch=branch, util=util,
-        include_file_list=include_file_list, currently_showing=currently_showing,
+        file_changes=file_changes, currently_showing=currently_showing,
         **templatefunctions)
 
 

=== modified file 'loggerhead/templates/revision.pt'
--- loggerhead/templates/revision.pt	2009-03-17 03:49:33 +0000
+++ loggerhead/templates/revision.pt	2009-03-19 00:44:05 +0000
@@ -96,7 +96,7 @@
           </ul>
         </tal:we-are-comparing>
 
-        <tal:revision-info replace="structure python:revisioninfo(url, branch, change, 'fragment', specific_path)" />
+        <tal:revision-info replace="structure python:revisioninfo(url, branch, change, file_changes, specific_path)" />
         <tal:specific-path condition="not:specific_path">
           <p class="expand show_if_js" id="expand_all"><a href="#">
               <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png')"
@@ -116,62 +116,85 @@
       </tal:block>
 
       <div metal:fill-slot="content">
-        <div class="diff"
-             tal:repeat="item diffs" tal:attributes="id string:diff-${item/index}">
+        <tal:block condition="specific_path">
+          <div class="diff">
 
-          <div  class="diffBox">
-            <a tal:attributes="href python:url(['/revision', change.revno, item.filename], clear=1);
-                               id string:${item/filename};
-                               title string:View changes to ${item/filename} only"
-               class="the-link">
-              <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png');
-                                   title python:branch.static_url('/static/images/treeCollapsed.png');
-                                   alt python:branch.static_url('/static/images/treeExpanded.png')"
-                   class="expand_diff" tal:condition="not:specific_path" />
-              <img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png');
-                                   title python:branch.static_url('/static/images/treeCollapsed.png');
-                                   alt python:branch.static_url('/static/images/treeExpanded.png')"
-                   class="expand_diff" tal:condition="specific_path" />
-              <tal:b content="item/filename" />
-            </a>
-          </div>
-          <div style="overflow: hidden">
-            <div class="container">
-              <div class="loading" style="display:none">
-                <img tal:attributes="src python:branch.static_url('/static/images/spinner.gif')" />
-              </div>
-              <div class="diffinfo" tal:condition="not:specific_path">
-                <div class="source_target" >
+            <div  class="diffBox">
+              <a tal:attributes="href python:url(['/revision', change.revno, specific_path], clear=1);
+                                 id string:${specific_path};
+                                 title string:View changes to ${specific_path} only"
+                 class="the-link">
+                <img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png');
+                                     title python:branch.static_url('/static/images/treeCollapsed.png');
+                                     alt python:branch.static_url('/static/images/treeExpanded.png')"
+                     class="expand_diff"/>
+                <tal:b content="specific_path" />
+              </a>
+            </div>
+            <div style="overflow: hidden">
+              <div class="container">
+                <div class="loading" style="display:none">
+                  <img tal:attributes="src python:branch.static_url('/static/images/spinner.gif')" />
                 </div>
-              </div>
-              <div class="diffinfo" tal:condition="specific_path">
-                <div class="pseudotable unified"
-                     tal:repeat="chunk item/chunks">
-
-                  <tal:block condition="not:repeat/chunk/start">
-                    <div class="pseudorow context-row">
-                      <div class="lineNumber separate"></div>
-                      <div class="lineNumber second separate"></div>
-                      <div class="code separate"></div>
+                <div class="diffinfo">
+                  <div class="pseudotable unified"
+                       tal:repeat="chunk diff_chunks">
+
+                    <tal:block condition="not:repeat/chunk/start">
+                      <div class="pseudorow context-row">
+                        <div class="lineNumber separate"></div>
+                        <div class="lineNumber second separate"></div>
+                        <div class="code separate"></div>
+                        <div class="clear"><!-- --></div>
+                      </div>
+                    </tal:block>
+
+                    <div tal:repeat="line chunk/diff"
+                         tal:attributes="class string:pseudorow ${line/type}-row">
+                      <div class="lineNumber first"
+                           tal:content="structure python:util.fill_div(line.old_lineno)"></div>
+                      <div class="lineNumber second"
+                           tal:content="structure python:util.fill_div(line.new_lineno)"></div>
+                      <div tal:attributes="class string:code ${line/type}"
+                           tal:content="structure python:util.fill_div(util.html_clean(line.line))"></div>
                       <div class="clear"><!-- --></div>
                     </div>
-                  </tal:block>
-
-                  <div tal:repeat="line chunk/diff"
-                       tal:attributes="class string:pseudorow ${line/type}-row">
-                    <div class="lineNumber first"
-                         tal:content="structure python:util.fill_div(line.old_lineno)"></div>
-                    <div class="lineNumber second"
-                         tal:content="structure python:util.fill_div(line.new_lineno)"></div>
-                    <div tal:attributes="class string:code ${line/type}"
-                         tal:content="structure python:util.fill_div(util.html_clean(line.line))"></div>
-                    <div class="clear"><!-- --></div>
-                  </div>
-                </div>
-              </div>
-            </div>
-          </div>
-        </div>
+                  </div>
+                </div>
+              </div>
+            </div>
+          </div>
+        </tal:block>
+
+        <tal:block condition="not:specific_path">
+          <div class="diff"
+               tal:repeat="item file_changes/text_changes" tal:attributes="id string:diff-${item/index}">
+
+            <div  class="diffBox">
+              <a tal:attributes="href python:url(['/revision', change.revno, item.filename], clear=1);
+                                 id string:${item/filename};
+                                 title string:View changes to ${item/filename} only"
+                 class="the-link">
+                <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png');
+                                     title python:branch.static_url('/static/images/treeCollapsed.png');
+                                     alt python:branch.static_url('/static/images/treeExpanded.png')"
+                     class="expand_diff" />
+                <tal:b content="item/filename" />
+              </a>
+            </div>
+            <div style="overflow: hidden">
+              <div class="container">
+                <div class="loading" style="display:none">
+                  <img tal:attributes="src python:branch.static_url('/static/images/spinner.gif')" />
+                </div>
+                <div class="diffinfo">
+                  <div class="source_target" >
+                  </div>
+                </div>
+              </div>
+            </div>
+          </div>
+        </tal:block>
 
         <ul tal:condition="python:navigation.prev_page_revid or navigation.next_page_revid"
             id="pages">

=== modified file 'loggerhead/templates/revisionfilechanges.pt'
--- loggerhead/templates/revisionfilechanges.pt	2009-03-05 23:41:51 +0000
+++ loggerhead/templates/revisionfilechanges.pt	2009-03-19 00:05:41 +0000
@@ -1,5 +1,5 @@
 <tal:block>
-  <ul tal:repeat="added entry/changes/added">
+  <ul tal:repeat="added file_changes/added">
     <tal:block condition="repeat/added/start">
       <li class="desc">files added:</li>
     </tal:block>
@@ -11,7 +11,7 @@
     </li>
   </ul>
 
-  <ul tal:repeat="removed entry/changes/removed">
+  <ul tal:repeat="removed file_changes/removed">
     <tal:block condition="repeat/removed/start">
       <li class="desc">files removed:</li>
     </tal:block>
@@ -23,7 +23,7 @@
     </li>
   </ul>
 
-  <ul tal:repeat="renamed entry/changes/renamed">
+  <ul tal:repeat="renamed file_changes/renamed">
     <tal:block condition="repeat/renamed/start">
       <li class="desc">files renamed:</li>
     </tal:block>
@@ -39,7 +39,7 @@
     </li>
   </ul>
 
-  <ul tal:repeat="item entry/changes/modified">
+  <ul tal:repeat="item file_changes/modified">
     <tal:block condition="repeat/item/start">
       <li class="desc">files modified:</li>
     </tal:block>

=== modified file 'loggerhead/templates/revisioninfo.pt'
--- loggerhead/templates/revisioninfo.pt	2009-03-18 04:52:57 +0000
+++ loggerhead/templates/revisioninfo.pt	2009-03-19 00:18:46 +0000
@@ -15,8 +15,8 @@
         <div class="revid" tal:content="string:Revision ID: ${change/revid}"></div>
         <div class="information" tal:content="structure python:util.fixed_width(change.comment)"></div>
     </div>
-    <ul id="list-files" tal:condition="include_file_list">
-      <tal:block content="structure python:file_change_summary(url, change, 'fragment', currently_showing)" />
+    <ul id="list-files" tal:condition="file_changes">
+      <tal:block content="structure python:file_change_summary(url, change, file_changes, 'fragment', currently_showing)" />
     </ul>
     <div class="clear"><!-- --></div>
 </div>

=== modified file 'loggerhead/templates/revlog.pt'
--- loggerhead/templates/revlog.pt	2009-03-16 23:30:18 +0000
+++ loggerhead/templates/revlog.pt	2009-03-19 00:27:08 +0000
@@ -16,6 +16,6 @@
          title="Show history" class="link"></a>
     </li>
     <li class="committerli" tal:content="python:', '.join(util.hide_emails(entry.authors))"></li>
-    <tal:block content="structure python:file_change_summary(url, entry)" />
+    <tal:block content="structure python:file_change_summary(url, entry, file_changes)" />
   </ul>
 </div>

